# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/apollo/events.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.apollo import submission_pb2 as eolymp_dot_apollo_dot_submission__pb2
from eolymp.apollo import score_pb2 as eolymp_dot_apollo_dot_score__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/apollo/events.proto',
  package='eolymp.apollo',
  syntax='proto3',
  serialized_options=b'Z3github.com/eolymp/contracts/go/eolymp/apollo;apollo',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x65olymp/apollo/events.proto\x12\reolymp.apollo\x1a\x1e\x65olymp/apollo/submission.proto\x1a\x19\x65olymp/apollo/score.proto\"Y\n\x18SubmissionCompletedEvent\x12-\n\nsubmission\x18\x01 \x01(\x0b\x32\x19.eolymp.apollo.Submission\x12\x0e\n\x06update\x18\x02 \x01(\x08\"8\n\x11ScoreUpdatedEvent\x12#\n\x05score\x18\x01 \x01(\x0b\x32\x14.eolymp.apollo.Score\"5\n\x0eStarAddedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"7\n\x10StarRemovedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\tB5Z3github.com/eolymp/contracts/go/eolymp/apollo;apollob\x06proto3'
  ,
  dependencies=[eolymp_dot_apollo_dot_submission__pb2.DESCRIPTOR,eolymp_dot_apollo_dot_score__pb2.DESCRIPTOR,])




_SUBMISSIONCOMPLETEDEVENT = _descriptor.Descriptor(
  name='SubmissionCompletedEvent',
  full_name='eolymp.apollo.SubmissionCompletedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='submission', full_name='eolymp.apollo.SubmissionCompletedEvent.submission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update', full_name='eolymp.apollo.SubmissionCompletedEvent.update', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=104,
  serialized_end=193,
)


_SCOREUPDATEDEVENT = _descriptor.Descriptor(
  name='ScoreUpdatedEvent',
  full_name='eolymp.apollo.ScoreUpdatedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.apollo.ScoreUpdatedEvent.score', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=195,
  serialized_end=251,
)


_STARADDEDEVENT = _descriptor.Descriptor(
  name='StarAddedEvent',
  full_name='eolymp.apollo.StarAddedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.apollo.StarAddedEvent.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.apollo.StarAddedEvent.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=253,
  serialized_end=306,
)


_STARREMOVEDEVENT = _descriptor.Descriptor(
  name='StarRemovedEvent',
  full_name='eolymp.apollo.StarRemovedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.apollo.StarRemovedEvent.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.apollo.StarRemovedEvent.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=308,
  serialized_end=363,
)

_SUBMISSIONCOMPLETEDEVENT.fields_by_name['submission'].message_type = eolymp_dot_apollo_dot_submission__pb2._SUBMISSION
_SCOREUPDATEDEVENT.fields_by_name['score'].message_type = eolymp_dot_apollo_dot_score__pb2._SCORE
DESCRIPTOR.message_types_by_name['SubmissionCompletedEvent'] = _SUBMISSIONCOMPLETEDEVENT
DESCRIPTOR.message_types_by_name['ScoreUpdatedEvent'] = _SCOREUPDATEDEVENT
DESCRIPTOR.message_types_by_name['StarAddedEvent'] = _STARADDEDEVENT
DESCRIPTOR.message_types_by_name['StarRemovedEvent'] = _STARREMOVEDEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SubmissionCompletedEvent = _reflection.GeneratedProtocolMessageType('SubmissionCompletedEvent', (_message.Message,), {
  'DESCRIPTOR' : _SUBMISSIONCOMPLETEDEVENT,
  '__module__' : 'eolymp.apollo.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.apollo.SubmissionCompletedEvent)
  })
_sym_db.RegisterMessage(SubmissionCompletedEvent)

ScoreUpdatedEvent = _reflection.GeneratedProtocolMessageType('ScoreUpdatedEvent', (_message.Message,), {
  'DESCRIPTOR' : _SCOREUPDATEDEVENT,
  '__module__' : 'eolymp.apollo.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.apollo.ScoreUpdatedEvent)
  })
_sym_db.RegisterMessage(ScoreUpdatedEvent)

StarAddedEvent = _reflection.GeneratedProtocolMessageType('StarAddedEvent', (_message.Message,), {
  'DESCRIPTOR' : _STARADDEDEVENT,
  '__module__' : 'eolymp.apollo.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.apollo.StarAddedEvent)
  })
_sym_db.RegisterMessage(StarAddedEvent)

StarRemovedEvent = _reflection.GeneratedProtocolMessageType('StarRemovedEvent', (_message.Message,), {
  'DESCRIPTOR' : _STARREMOVEDEVENT,
  '__module__' : 'eolymp.apollo.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.apollo.StarRemovedEvent)
  })
_sym_db.RegisterMessage(StarRemovedEvent)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
