# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/submission.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/judge/submission.proto',
  package='eolymp.judge',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/judge;judge',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1d\x65olymp/judge/submission.proto\x12\x0c\x65olymp.judge\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8b\x0c\n\nSubmission\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\ncontest_id\x18\x02 \x01(\t\x12\x12\n\nproblem_id\x18\x03 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x04 \x01(\t\x12\x30\n\x0csubmitted_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04lang\x18\n \x01(\t\x12\x0e\n\x06source\x18\x0b \x01(\t\x12\x11\n\tsignature\x18\x0c \x01(\t\x12/\n\x06status\x18\x14 \x01(\x0e\x32\x1f.eolymp.judge.Submission.Status\x12\r\n\x05\x65rror\x18\x15 \x01(\t\x12\x0c\n\x04\x63ost\x18\x1e \x01(\x02\x12\r\n\x05score\x18\x1f \x01(\x02\x12\x12\n\npercentage\x18  \x01(\x02\x12.\n\x06groups\x18\x32 \x03(\x0b\x32\x1e.eolymp.judge.Submission.Group\x1a\x95\x03\n\x03Run\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0fwall_time_usage\x18\x02 \x01(\r\x12\x16\n\x0e\x63pu_time_usage\x18\x03 \x01(\r\x12\x14\n\x0cmemory_usage\x18\x04 \x01(\x04\x12\r\n\x05index\x18\n \x01(\r\x12\x0f\n\x07test_id\x18\x0b \x01(\t\x12\x0c\n\x04\x63ost\x18\x0c \x01(\x02\x12\r\n\x05score\x18\r \x01(\x02\x12\x33\n\x06status\x18\x14 \x01(\x0e\x32#.eolymp.judge.Submission.Run.Status\"\xc8\x01\n\x06Status\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\r\n\tEXECUTING\x10\x02\x12\x0b\n\x07TIMEOUT\x10\x03\x12\x11\n\rCPU_EXHAUSTED\x10\x04\x12\x13\n\x0fMEMORY_OVERFLOW\x10\x05\x12\x10\n\x0cWRONG_ANSWER\x10\x06\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x07\x12\x11\n\rRUNTIME_ERROR\x10\x08\x12\x16\n\x12VERIFICATION_ERROR\x10\t\x12\x0b\n\x07SKIPPED\x10\n\x12\x0b\n\x07\x42LOCKED\x10\x0b\x1a\xb3\x05\n\x05Group\x12\r\n\x05index\x18\x01 \x01(\r\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12\x35\n\x06status\x18\n \x01(\x0e\x32%.eolymp.judge.Submission.Group.Status\x12\x14\n\x0c\x64\x65pendencies\x18\x0b \x03(\r\x12\x0c\n\x04\x63ost\x18\x14 \x01(\x02\x12\r\n\x05score\x18\x15 \x01(\x02\x12@\n\x0cscoring_mode\x18\x16 \x01(\x0e\x32*.eolymp.judge.Submission.Group.ScoringMode\x12\x46\n\x0f\x66\x65\x65\x64\x62\x61\x63k_policy\x18\x1e \x01(\x0e\x32-.eolymp.judge.Submission.Group.FeedbackPolicy\x12\x17\n\x0fwall_time_usage\x18) \x01(\r\x12\x16\n\x0e\x63pu_time_usage\x18* \x01(\r\x12\x14\n\x0cmemory_usage\x18. \x01(\x04\x12*\n\x04runs\x18\x64 \x03(\x0b\x32\x1c.eolymp.judge.Submission.Run\"\xc9\x01\n\x06Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07\x42LOCKED\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0b\n\x07TESTING\x10\x03\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x04\x12\x0b\n\x07TIMEOUT\x10\x05\x12\x11\n\rCPU_EXHAUSTED\x10\x06\x12\x13\n\x0fMEMORY_OVERFLOW\x10\x07\x12\x10\n\x0cWRONG_ANSWER\x10\x08\x12\x11\n\rRUNTIME_ERROR\x10\t\x12\x16\n\x12VERIFICATION_ERROR\x10\n\x12\x0b\n\x07SKIPPED\x10\x0b\"*\n\x0bScoringMode\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04\x45\x41\x43H\x10\x01\x12\x07\n\x03\x41LL\x10\x02\"(\n\x0e\x46\x65\x65\x64\x62\x61\x63kPolicy\x12\x0c\n\x08\x43OMPLETE\x10\x00\x12\x08\n\x04ICPC\x10\x01\"_\n\x06Status\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0b\n\x07TESTING\x10\x02\x12\x0b\n\x07TIMEOUT\x10\x03\x12\x0c\n\x08\x43OMPLETE\x10\x04\x12\t\n\x05\x45RROR\x10\x05\x12\x0b\n\x07\x46\x41ILURE\x10\x06\x42\x33Z1github.com/eolymp/contracts/go/eolymp/judge;judgeb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_SUBMISSION_RUN_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='eolymp.judge.Submission.Run.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXECUTING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TIMEOUT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CPU_EXHAUSTED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MEMORY_OVERFLOW', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WRONG_ANSWER', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACCEPTED', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNTIME_ERROR', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VERIFICATION_ERROR', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SKIPPED', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BLOCKED', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=637,
  serialized_end=837,
)
_sym_db.RegisterEnumDescriptor(_SUBMISSION_RUN_STATUS)

_SUBMISSION_GROUP_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='eolymp.judge.Submission.Group.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BLOCKED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TESTING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACCEPTED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TIMEOUT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CPU_EXHAUSTED', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MEMORY_OVERFLOW', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WRONG_ANSWER', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNTIME_ERROR', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VERIFICATION_ERROR', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SKIPPED', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1244,
  serialized_end=1445,
)
_sym_db.RegisterEnumDescriptor(_SUBMISSION_GROUP_STATUS)

_SUBMISSION_GROUP_SCORINGMODE = _descriptor.EnumDescriptor(
  name='ScoringMode',
  full_name='eolymp.judge.Submission.Group.ScoringMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EACH', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1447,
  serialized_end=1489,
)
_sym_db.RegisterEnumDescriptor(_SUBMISSION_GROUP_SCORINGMODE)

_SUBMISSION_GROUP_FEEDBACKPOLICY = _descriptor.EnumDescriptor(
  name='FeedbackPolicy',
  full_name='eolymp.judge.Submission.Group.FeedbackPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMPLETE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ICPC', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1491,
  serialized_end=1531,
)
_sym_db.RegisterEnumDescriptor(_SUBMISSION_GROUP_FEEDBACKPOLICY)

_SUBMISSION_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='eolymp.judge.Submission.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TESTING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TIMEOUT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPLETE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILURE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1533,
  serialized_end=1628,
)
_sym_db.RegisterEnumDescriptor(_SUBMISSION_STATUS)


_SUBMISSION_RUN = _descriptor.Descriptor(
  name='Run',
  full_name='eolymp.judge.Submission.Run',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.judge.Submission.Run.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wall_time_usage', full_name='eolymp.judge.Submission.Run.wall_time_usage', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpu_time_usage', full_name='eolymp.judge.Submission.Run.cpu_time_usage', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memory_usage', full_name='eolymp.judge.Submission.Run.memory_usage', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='eolymp.judge.Submission.Run.index', index=4,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='test_id', full_name='eolymp.judge.Submission.Run.test_id', index=5,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cost', full_name='eolymp.judge.Submission.Run.cost', index=6,
      number=12, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.judge.Submission.Run.score', index=7,
      number=13, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='eolymp.judge.Submission.Run.status', index=8,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SUBMISSION_RUN_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=837,
)

_SUBMISSION_GROUP = _descriptor.Descriptor(
  name='Group',
  full_name='eolymp.judge.Submission.Group',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='eolymp.judge.Submission.Group.index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='testset_id', full_name='eolymp.judge.Submission.Group.testset_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='eolymp.judge.Submission.Group.status', index=2,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dependencies', full_name='eolymp.judge.Submission.Group.dependencies', index=3,
      number=11, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cost', full_name='eolymp.judge.Submission.Group.cost', index=4,
      number=20, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.judge.Submission.Group.score', index=5,
      number=21, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scoring_mode', full_name='eolymp.judge.Submission.Group.scoring_mode', index=6,
      number=22, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feedback_policy', full_name='eolymp.judge.Submission.Group.feedback_policy', index=7,
      number=30, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wall_time_usage', full_name='eolymp.judge.Submission.Group.wall_time_usage', index=8,
      number=41, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpu_time_usage', full_name='eolymp.judge.Submission.Group.cpu_time_usage', index=9,
      number=42, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memory_usage', full_name='eolymp.judge.Submission.Group.memory_usage', index=10,
      number=46, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runs', full_name='eolymp.judge.Submission.Group.runs', index=11,
      number=100, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SUBMISSION_GROUP_STATUS,
    _SUBMISSION_GROUP_SCORINGMODE,
    _SUBMISSION_GROUP_FEEDBACKPOLICY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=840,
  serialized_end=1531,
)

_SUBMISSION = _descriptor.Descriptor(
  name='Submission',
  full_name='eolymp.judge.Submission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.judge.Submission.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.Submission.contest_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.judge.Submission.problem_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='eolymp.judge.Submission.participant_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='submitted_at', full_name='eolymp.judge.Submission.submitted_at', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lang', full_name='eolymp.judge.Submission.lang', index=5,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='eolymp.judge.Submission.source', index=6,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='eolymp.judge.Submission.signature', index=7,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='eolymp.judge.Submission.status', index=8,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='eolymp.judge.Submission.error', index=9,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cost', full_name='eolymp.judge.Submission.cost', index=10,
      number=30, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.judge.Submission.score', index=11,
      number=31, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percentage', full_name='eolymp.judge.Submission.percentage', index=12,
      number=32, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groups', full_name='eolymp.judge.Submission.groups', index=13,
      number=50, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SUBMISSION_RUN, _SUBMISSION_GROUP, ],
  enum_types=[
    _SUBMISSION_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=1628,
)

_SUBMISSION_RUN.fields_by_name['status'].enum_type = _SUBMISSION_RUN_STATUS
_SUBMISSION_RUN.containing_type = _SUBMISSION
_SUBMISSION_RUN_STATUS.containing_type = _SUBMISSION_RUN
_SUBMISSION_GROUP.fields_by_name['status'].enum_type = _SUBMISSION_GROUP_STATUS
_SUBMISSION_GROUP.fields_by_name['scoring_mode'].enum_type = _SUBMISSION_GROUP_SCORINGMODE
_SUBMISSION_GROUP.fields_by_name['feedback_policy'].enum_type = _SUBMISSION_GROUP_FEEDBACKPOLICY
_SUBMISSION_GROUP.fields_by_name['runs'].message_type = _SUBMISSION_RUN
_SUBMISSION_GROUP.containing_type = _SUBMISSION
_SUBMISSION_GROUP_STATUS.containing_type = _SUBMISSION_GROUP
_SUBMISSION_GROUP_SCORINGMODE.containing_type = _SUBMISSION_GROUP
_SUBMISSION_GROUP_FEEDBACKPOLICY.containing_type = _SUBMISSION_GROUP
_SUBMISSION.fields_by_name['submitted_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SUBMISSION.fields_by_name['status'].enum_type = _SUBMISSION_STATUS
_SUBMISSION.fields_by_name['groups'].message_type = _SUBMISSION_GROUP
_SUBMISSION_STATUS.containing_type = _SUBMISSION
DESCRIPTOR.message_types_by_name['Submission'] = _SUBMISSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Submission = _reflection.GeneratedProtocolMessageType('Submission', (_message.Message,), {

  'Run' : _reflection.GeneratedProtocolMessageType('Run', (_message.Message,), {
    'DESCRIPTOR' : _SUBMISSION_RUN,
    '__module__' : 'eolymp.judge.submission_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.judge.Submission.Run)
    })
  ,

  'Group' : _reflection.GeneratedProtocolMessageType('Group', (_message.Message,), {
    'DESCRIPTOR' : _SUBMISSION_GROUP,
    '__module__' : 'eolymp.judge.submission_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.judge.Submission.Group)
    })
  ,
  'DESCRIPTOR' : _SUBMISSION,
  '__module__' : 'eolymp.judge.submission_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.Submission)
  })
_sym_db.RegisterMessage(Submission)
_sym_db.RegisterMessage(Submission.Run)
_sym_db.RegisterMessage(Submission.Group)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
