# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/wellknown/expression.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/wellknown/expression.proto',
  package='eolymp.wellknown',
  syntax='proto3',
  serialized_options=b'Z9github.com/eolymp/contracts/go/eolymp/wellknown;wellknown',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!eolymp/wellknown/expression.proto\x12\x10\x65olymp.wellknown\x1a\x1fgoogle/protobuf/timestamp.proto\"z\n\x0c\x45xpressionID\x12/\n\x02is\x18\x01 \x01(\x0e\x32#.eolymp.wellknown.ExpressionID.Type\x12\r\n\x05value\x18\x02 \x01(\t\"*\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\x12\r\n\tNOT_EQUAL\x10\x02\"\xca\x01\n\rExpressionInt\x12\x30\n\x02is\x18\x01 \x01(\x0e\x32$.eolymp.wellknown.ExpressionInt.Type\x12\r\n\x05value\x18\x02 \x01(\x05\"x\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\x12\r\n\tNOT_EQUAL\x10\x02\x12\x10\n\x0cGREATER_THAN\x10\x03\x12\x16\n\x12GREATER_THAN_EQUAL\x10\x04\x12\r\n\tLESS_THAN\x10\x05\x12\x13\n\x0fLESS_THAN_EQUAL\x10\x06\"\xce\x01\n\x0f\x45xpressionFloat\x12\x32\n\x02is\x18\x01 \x01(\x0e\x32&.eolymp.wellknown.ExpressionFloat.Type\x12\r\n\x05value\x18\x02 \x01(\x02\"x\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\x12\r\n\tNOT_EQUAL\x10\x02\x12\x10\n\x0cGREATER_THAN\x10\x03\x12\x16\n\x12GREATER_THAN_EQUAL\x10\x04\x12\r\n\tLESS_THAN\x10\x05\x12\x13\n\x0fLESS_THAN_EQUAL\x10\x06\"\x92\x01\n\x10\x45xpressionString\x12\x33\n\x02is\x18\x01 \x01(\x0e\x32\'.eolymp.wellknown.ExpressionString.Type\x12\r\n\x05value\x18\x02 \x01(\t\":\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\x12\r\n\tNOT_EQUAL\x10\x02\x12\x0e\n\nCONTAINING\x10\x03\"~\n\x0e\x45xpressionEnum\x12\x31\n\x02is\x18\x01 \x01(\x0e\x32%.eolymp.wellknown.ExpressionEnum.Type\x12\r\n\x05value\x18\x02 \x01(\t\"*\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\x12\r\n\tNOT_EQUAL\x10\x02\"o\n\x0e\x45xpressionBool\x12\x31\n\x02is\x18\x01 \x01(\x0e\x32%.eolymp.wellknown.ExpressionBool.Type\x12\r\n\x05value\x18\x02 \x01(\x08\"\x1b\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\"\xf2\x01\n\x13\x45xpressionTimestamp\x12\x36\n\x02is\x18\x01 \x01(\x0e\x32*.eolymp.wellknown.ExpressionTimestamp.Type\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"x\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\x12\r\n\tNOT_EQUAL\x10\x02\x12\x10\n\x0cGREATER_THAN\x10\x03\x12\x16\n\x12GREATER_THAN_EQUAL\x10\x04\x12\r\n\tLESS_THAN\x10\x05\x12\x13\n\x0fLESS_THAN_EQUAL\x10\x06\x42;Z9github.com/eolymp/contracts/go/eolymp/wellknown;wellknownb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_EXPRESSIONID_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.wellknown.ExpressionID.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EQUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_EQUAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=168,
  serialized_end=210,
)
_sym_db.RegisterEnumDescriptor(_EXPRESSIONID_TYPE)

_EXPRESSIONINT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.wellknown.ExpressionInt.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EQUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_EQUAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREATER_THAN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREATER_THAN_EQUAL', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LESS_THAN', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LESS_THAN_EQUAL', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=295,
  serialized_end=415,
)
_sym_db.RegisterEnumDescriptor(_EXPRESSIONINT_TYPE)

_EXPRESSIONFLOAT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.wellknown.ExpressionFloat.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EQUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_EQUAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREATER_THAN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREATER_THAN_EQUAL', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LESS_THAN', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LESS_THAN_EQUAL', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=295,
  serialized_end=415,
)
_sym_db.RegisterEnumDescriptor(_EXPRESSIONFLOAT_TYPE)

_EXPRESSIONSTRING_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.wellknown.ExpressionString.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EQUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_EQUAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTAINING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=715,
  serialized_end=773,
)
_sym_db.RegisterEnumDescriptor(_EXPRESSIONSTRING_TYPE)

_EXPRESSIONENUM_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.wellknown.ExpressionEnum.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EQUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_EQUAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=168,
  serialized_end=210,
)
_sym_db.RegisterEnumDescriptor(_EXPRESSIONENUM_TYPE)

_EXPRESSIONBOOL_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.wellknown.ExpressionBool.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EQUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=168,
  serialized_end=195,
)
_sym_db.RegisterEnumDescriptor(_EXPRESSIONBOOL_TYPE)

_EXPRESSIONTIMESTAMP_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.wellknown.ExpressionTimestamp.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EQUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_EQUAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREATER_THAN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREATER_THAN_EQUAL', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LESS_THAN', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LESS_THAN_EQUAL', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=295,
  serialized_end=415,
)
_sym_db.RegisterEnumDescriptor(_EXPRESSIONTIMESTAMP_TYPE)


_EXPRESSIONID = _descriptor.Descriptor(
  name='ExpressionID',
  full_name='eolymp.wellknown.ExpressionID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is', full_name='eolymp.wellknown.ExpressionID.is', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='eolymp.wellknown.ExpressionID.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EXPRESSIONID_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=88,
  serialized_end=210,
)


_EXPRESSIONINT = _descriptor.Descriptor(
  name='ExpressionInt',
  full_name='eolymp.wellknown.ExpressionInt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is', full_name='eolymp.wellknown.ExpressionInt.is', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='eolymp.wellknown.ExpressionInt.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EXPRESSIONINT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=213,
  serialized_end=415,
)


_EXPRESSIONFLOAT = _descriptor.Descriptor(
  name='ExpressionFloat',
  full_name='eolymp.wellknown.ExpressionFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is', full_name='eolymp.wellknown.ExpressionFloat.is', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='eolymp.wellknown.ExpressionFloat.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EXPRESSIONFLOAT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=418,
  serialized_end=624,
)


_EXPRESSIONSTRING = _descriptor.Descriptor(
  name='ExpressionString',
  full_name='eolymp.wellknown.ExpressionString',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is', full_name='eolymp.wellknown.ExpressionString.is', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='eolymp.wellknown.ExpressionString.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EXPRESSIONSTRING_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=627,
  serialized_end=773,
)


_EXPRESSIONENUM = _descriptor.Descriptor(
  name='ExpressionEnum',
  full_name='eolymp.wellknown.ExpressionEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is', full_name='eolymp.wellknown.ExpressionEnum.is', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='eolymp.wellknown.ExpressionEnum.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EXPRESSIONENUM_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=775,
  serialized_end=901,
)


_EXPRESSIONBOOL = _descriptor.Descriptor(
  name='ExpressionBool',
  full_name='eolymp.wellknown.ExpressionBool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is', full_name='eolymp.wellknown.ExpressionBool.is', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='eolymp.wellknown.ExpressionBool.value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EXPRESSIONBOOL_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=903,
  serialized_end=1014,
)


_EXPRESSIONTIMESTAMP = _descriptor.Descriptor(
  name='ExpressionTimestamp',
  full_name='eolymp.wellknown.ExpressionTimestamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is', full_name='eolymp.wellknown.ExpressionTimestamp.is', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='eolymp.wellknown.ExpressionTimestamp.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EXPRESSIONTIMESTAMP_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1017,
  serialized_end=1259,
)

_EXPRESSIONID.fields_by_name['is'].enum_type = _EXPRESSIONID_TYPE
_EXPRESSIONID_TYPE.containing_type = _EXPRESSIONID
_EXPRESSIONINT.fields_by_name['is'].enum_type = _EXPRESSIONINT_TYPE
_EXPRESSIONINT_TYPE.containing_type = _EXPRESSIONINT
_EXPRESSIONFLOAT.fields_by_name['is'].enum_type = _EXPRESSIONFLOAT_TYPE
_EXPRESSIONFLOAT_TYPE.containing_type = _EXPRESSIONFLOAT
_EXPRESSIONSTRING.fields_by_name['is'].enum_type = _EXPRESSIONSTRING_TYPE
_EXPRESSIONSTRING_TYPE.containing_type = _EXPRESSIONSTRING
_EXPRESSIONENUM.fields_by_name['is'].enum_type = _EXPRESSIONENUM_TYPE
_EXPRESSIONENUM_TYPE.containing_type = _EXPRESSIONENUM
_EXPRESSIONBOOL.fields_by_name['is'].enum_type = _EXPRESSIONBOOL_TYPE
_EXPRESSIONBOOL_TYPE.containing_type = _EXPRESSIONBOOL
_EXPRESSIONTIMESTAMP.fields_by_name['is'].enum_type = _EXPRESSIONTIMESTAMP_TYPE
_EXPRESSIONTIMESTAMP.fields_by_name['value'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXPRESSIONTIMESTAMP_TYPE.containing_type = _EXPRESSIONTIMESTAMP
DESCRIPTOR.message_types_by_name['ExpressionID'] = _EXPRESSIONID
DESCRIPTOR.message_types_by_name['ExpressionInt'] = _EXPRESSIONINT
DESCRIPTOR.message_types_by_name['ExpressionFloat'] = _EXPRESSIONFLOAT
DESCRIPTOR.message_types_by_name['ExpressionString'] = _EXPRESSIONSTRING
DESCRIPTOR.message_types_by_name['ExpressionEnum'] = _EXPRESSIONENUM
DESCRIPTOR.message_types_by_name['ExpressionBool'] = _EXPRESSIONBOOL
DESCRIPTOR.message_types_by_name['ExpressionTimestamp'] = _EXPRESSIONTIMESTAMP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExpressionID = _reflection.GeneratedProtocolMessageType('ExpressionID', (_message.Message,), {
  'DESCRIPTOR' : _EXPRESSIONID,
  '__module__' : 'eolymp.wellknown.expression_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.wellknown.ExpressionID)
  })
_sym_db.RegisterMessage(ExpressionID)

ExpressionInt = _reflection.GeneratedProtocolMessageType('ExpressionInt', (_message.Message,), {
  'DESCRIPTOR' : _EXPRESSIONINT,
  '__module__' : 'eolymp.wellknown.expression_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.wellknown.ExpressionInt)
  })
_sym_db.RegisterMessage(ExpressionInt)

ExpressionFloat = _reflection.GeneratedProtocolMessageType('ExpressionFloat', (_message.Message,), {
  'DESCRIPTOR' : _EXPRESSIONFLOAT,
  '__module__' : 'eolymp.wellknown.expression_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.wellknown.ExpressionFloat)
  })
_sym_db.RegisterMessage(ExpressionFloat)

ExpressionString = _reflection.GeneratedProtocolMessageType('ExpressionString', (_message.Message,), {
  'DESCRIPTOR' : _EXPRESSIONSTRING,
  '__module__' : 'eolymp.wellknown.expression_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.wellknown.ExpressionString)
  })
_sym_db.RegisterMessage(ExpressionString)

ExpressionEnum = _reflection.GeneratedProtocolMessageType('ExpressionEnum', (_message.Message,), {
  'DESCRIPTOR' : _EXPRESSIONENUM,
  '__module__' : 'eolymp.wellknown.expression_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.wellknown.ExpressionEnum)
  })
_sym_db.RegisterMessage(ExpressionEnum)

ExpressionBool = _reflection.GeneratedProtocolMessageType('ExpressionBool', (_message.Message,), {
  'DESCRIPTOR' : _EXPRESSIONBOOL,
  '__module__' : 'eolymp.wellknown.expression_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.wellknown.ExpressionBool)
  })
_sym_db.RegisterMessage(ExpressionBool)

ExpressionTimestamp = _reflection.GeneratedProtocolMessageType('ExpressionTimestamp', (_message.Message,), {
  'DESCRIPTOR' : _EXPRESSIONTIMESTAMP,
  '__module__' : 'eolymp.wellknown.expression_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.wellknown.ExpressionTimestamp)
  })
_sym_db.RegisterMessage(ExpressionTimestamp)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
