# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class KeeperClient:
    def __init__(self, transport):
        self.transport = transport

    def CreateObject(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.keeper.Keeper/CreateObject",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.keeper.CreateObjectOutput"),
            **kwargs,
        )

    def DescribeObject(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.keeper.Keeper/DescribeObject",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.keeper.DescribeObjectOutput"),
            **kwargs,
        )

    def DownloadObject(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.keeper.Keeper/DownloadObject",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.keeper.DownloadObjectOutput"),
            **kwargs,
        )

